@@ -110,7 +110,8 @@ class Deployments(WMLResource):
                  >>> meta_props = {
                  >>> wml_client.deployments.ConfigurationMetaNames.NAME: "SAMPLE DEPLOYMENT NAME",
                  >>> wml_client.deployments.ConfigurationMetaNames.ONLINE: {},
-                 >>> wml_client.deployments.ConfigurationMetaNames.HARDWARE_SPEC : { "id":  "e7ed1d6c-2e89-42d7-aed5-8sb972c1d2b"}
+                 >>> wml_client.deployments.ConfigurationMetaNames.HARDWARE_SPEC : { "id":  "e7ed1d6c-2e89-42d7-aed5-8sb972c1d2b"},
+                 >>> wml_client.deployments.ConfigurationMetaNames.SERVING_NAME : 'sample_deployment'
                  >>> }
                  >>> deployment_details = client.deployments.create(artifact_uid, meta_props)
 
@@ -839,7 +840,8 @@ class Deployments(WMLResource):
         params = self._client._params()
         details = self.get_details(virtual_deployment_uid)
         download_url = self.get_download_url(details)
-        if any([self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40, self._client.ICP_45]):
+        if any([self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40, self._client.ICP_45,
+                self._client.ICP_46]):
             download_url = download_url + "&version=" + self._client.version_param
             params = None
         response = requests.get(
