@@ -878,11 +878,13 @@ class BaseDataConnection(ABC):
                                            flight_parameters: dict = None,
                                            headers: dict = None,
                                            number_of_batch_rows: int = None,
-                                           sample_size_limit: int = DEFAULT_SAMPLE_SIZE_LIMIT,
                                            sampling_type: str = DEFAULT_SAMPLING_TYPE,
                                            return_data_as_iterator: bool = False,
                                            enable_sampling: bool = True,
-                                           _return_subsampling_stats: bool = False):
+                                           _return_subsampling_stats: bool = False,
+                                           total_size_limit=DEFAULT_SAMPLE_SIZE_LIMIT,
+                                           total_nrows_limit=None,
+                                           total_percentage_limit=1.0):
 
         is_lib_installed(lib_name='pyarrow', minimum_version='3.0.0', install=True)
 
@@ -917,8 +919,10 @@ class BaseDataConnection(ABC):
             _return_subsampling_stats=_return_subsampling_stats,
             number_of_batch_rows=number_of_batch_rows,
             sampling_type=sampling_type,
-            sample_size_limit=sample_size_limit,
-            _wml_client=self._wml_client
+            _wml_client=self._wml_client,
+            total_size_limit=total_size_limit,
+            total_nrows_limit=total_nrows_limit,
+            total_percentage_limit=total_percentage_limit
         )
 
         iterable_dataset = ExperimentIterableDataset(**experiment_iterable_dataset_setup_parameters)
