@@ -218,6 +218,8 @@ class FlightConnection:
         self.return_subsampling_stats = return_subsampling_stats
         self.total_size = 0  # total size of downloaded data in Bytes (only in single thread)
         self.downloaded_data_size = 0  # total size of downloaded data in Bytes (every case)
+        self.downloaded_data_nrows = 0  # total number  of downloaded data in rows (every case)
+
         self.batch_queue = []
 
         self.flight_parameters = flight_parameters if flight_parameters is not None else {}
@@ -402,14 +404,7 @@ class FlightConnection:
         except flight.FlightInternalError as e:
             logger.debug(f"Caught FlightInternalError in get_endpoints: {str(e)}")
             if 'CDICO2034E' in str(e):
-                if 'The property [infer_schema] is not supported.' in str(e):
-                    for source_command in self._select_source_command(infer_schema=False):
-                        info = self.flight_client.get_flight_info(
-                            flight.FlightDescriptor.for_command(source_command)
-                        )
-                        yield info.endpoints
-
-                elif 'The property [infer_as_varchar] is not supported.' in str(e):
+                if 'The property [infer_as_varchar] is not supported.' in str(e):
                     # Don't sent infer_as_varchar in flight command and try again.
                     self.infer_as_varchar = None
                     for source_command in self._select_source_command():
@@ -433,15 +428,7 @@ class FlightConnection:
                 raise WrongFileLocation(reason=str(e))
 
             elif 'CDICO9999E' in str(e):
-                if 'Bad Request' in str(e):
-                    for source_command in self._select_source_command(infer_schema=False):
-                        info = self.flight_client.get_flight_info(
-                            flight.FlightDescriptor.for_command(source_command)
-                        )
-                        yield info.endpoints
-
-                else:
-                    raise WrongLocationProperty(reason=str(e))
+                raise WrongLocationProperty(reason=str(e))
             else:
                 raise e
 
@@ -557,10 +544,11 @@ class FlightConnection:
 
         with self.lock_read:
             self.downloaded_data_size += mini_batch_size
+            self.downloaded_data_nrows += len(data)
 
         if mb_counter % 10 == 0:
             logger.debug(f"RC {thread_number}: Total downloaded data size: "
-                         f"{self.downloaded_data_size / 1024 / 1024}MB")
+                         f"{self.downloaded_data_size / 1024 / 1024}MB, rows: {self.downloaded_data_nrows}")
 
         return data, row_size
 
@@ -672,9 +660,10 @@ class FlightConnection:
                 self.yielded_nrows += len(data)
                 if self.return_subsampling_stats:
                     data_stats = {"data_size": self.downloaded_data_size,
+                                  "data_nrows": self.downloaded_data_nrows,
                                   "data_batch_size": sys.getsizeof(data),
                                   "data_batch_nrows": len(data),
-                                  "no_batches": self.downloaded_data_size // sys.getsizeof(data)}
+                                  "no_batches": self.downloaded_data_nrows // len(data)}
                     yield data, data_stats
                 else:
                     yield data
@@ -781,7 +770,7 @@ class FlightConnection:
                 if self.row_size > 0:
                     self.subsampled_data = self._sample_data_to_percentage(self.total_percentage_limit,
                                                                            self.subsampled_data,
-                                                                           self.downloaded_data_size // self.row_size)
+                                                                           self.downloaded_data_nrows)
                 self.subsampled_data = self._process_data(self.subsampled_data)
                 self.yielded_nrows += len(self.subsampled_data)
                 yield self.subsampled_data
@@ -981,8 +970,9 @@ class FlightConnection:
         while True:
             try:
                 if threads_finished == self.max_flight_batch_number:
-                    data = pd.concat(logical_batch)  # flush last data
-                    yield self._process_data(data)
+                    if logical_batch:
+                        data = pd.concat(logical_batch)  # flush last data
+                        yield self._process_data(data)
                     break
 
                 logger.debug("LB: Waiting for mini batch to appear in the queue...")
