@@ -462,16 +462,16 @@ class Pipelines(WMLResource):
         Pipelines._validate_type(limit, u'limit', int, False)
         if self._client.WSD:
             url = self._client.service_instance._href_definitions.get_model_definition_assets_href()
-            response = self._get_artifact_details(url, pipeline_uid, limit, 'definitions', summary="False")
+            response = self._get_artifact_details(url, pipeline_uid, limit, 'pipeline' if pipeline_uid else 'pipelines', summary="False")
             return self._wsd_get_required_element_from_response(response)
         else:
             url = self._client.service_instance._href_definitions.get_pipelines_href()
 
         if pipeline_uid is None:
-            return self._get_artifact_details(url, pipeline_uid, limit, 'definitions', summary="False",
+            return self._get_artifact_details(url, pipeline_uid, limit, 'pipelines', summary="False",
                                               _async=asynchronous, _all=get_all)
         else:
-            return self._get_artifact_details(url, pipeline_uid, limit, 'definitions',summary="False")
+            return self._get_artifact_details(url, pipeline_uid, limit, 'pipeline',summary="False")
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_revision_details(self, pipeline_uid, rev_uid):
