@@ -19,6 +19,7 @@ from ibm_watson_machine_learning.metanames import ShinyMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure, ForbiddenActionForGitBasedProject
 import os
+import warnings
 
 _DEFAULT_LIST_LENGTH = 50
 
@@ -140,17 +141,27 @@ class Shiny(WMLResource):
 
         if self._client.ICP_46:
             shiny_sw_specs = ('rstudio_r4.2',)
+            deprecated_shiny_sw_specs = ('shiny-r3.6',)
         else:
             shiny_sw_specs = ('shiny-r3.6',)
+            deprecated_shiny_sw_specs = ()
         shiny_sw_spec_ids = [self._client.software_specifications.get_id_by_name(sw_name)
                                for sw_name in shiny_sw_specs]
+        deprecated_shiny_sw_spec_ids = [self._client.software_specifications.get_id_by_name(sw_name)
+                               for sw_name in deprecated_shiny_sw_specs]
 
-        if shiny_sw_spec_id and shiny_sw_spec_id not in shiny_sw_spec_ids:
+        if shiny_sw_spec_id and shiny_sw_spec_id not in shiny_sw_spec_ids + deprecated_shiny_sw_spec_ids:
             raise WMLClientError(
                 f"For R Shiny assets, only base software specs {','.join(shiny_sw_specs)} "
                 "are supported. Specify "
                 "the id you get via "
                 "self._client.software_specifications.get_id_by_name(sw_name)")
+        elif shiny_sw_spec_id and shiny_sw_spec_id in deprecated_shiny_sw_spec_ids:
+            warnings.warn("Provided software spec is deprecated for R Shiny assets. "
+                     f"Only base software specs {','.join(shiny_sw_specs)} "
+                     "are supported. Specify "
+                     "the id you get via "
+                     "self._client.software_specifications.get_id_by_name(sw_name)")
 
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             asset_meta = {
